@@ -1,21 +1,19 @@
 """Schedule schema."""
 
-from typing import Optional
-
-from blackcap.schemas.job import Job
-
 from pydantic import BaseModel
 from pydantic.types import UUID4
 
+from blackcap.schemas.job import Job
+
 
 class Schedule(BaseModel):
     """Schedule schema."""
 
-    schedule_id: Optional[UUID4]
-    user_id: Optional[UUID4]
+    schedule_id: UUID4
+    user_id: UUID4
     job_id: UUID4
-    job: Optional[Job]
-    assigned_cluster_id: Optional[UUID4]
-    messenger: Optional[str]
-    messenger_queue: Optional[str]
+    job: Job
+    assigned_cluster_id: UUID4
+    messenger: str
+    messenger_queue: str
     status: str = "PENDING"
